summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/mapdef.h
diff options
context:
space:
mode:
authordshaligram <dshaligram@c06c8d41-db1a-0410-9941-cceddc491573>2008-05-05 13:33:29 +0000
committerdshaligram <dshaligram@c06c8d41-db1a-0410-9941-cceddc491573>2008-05-05 13:33:29 +0000
commitff2f267821153758bcd691e73b1b409c62f0c4e0 (patch)
tree11f18df98aad81ddfa9798dafd67eceb3b4ed510 /crawl-ref/source/mapdef.h
parent3423bbab5a0f024eeafffe6b8260c8c088647db1 (diff)
downloadcrawl-ref-ff2f267821153758bcd691e73b1b409c62f0c4e0.tar.gz
crawl-ref-ff2f267821153758bcd691e73b1b409c62f0c4e0.zip
Cleaned up monster generation functions, separate monster zombie type from monster number. May be buggy.
Allow hydra zombies (they currently do not get the right number of heads). git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@4872 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/mapdef.h')
-rw-r--r--crawl-ref/source/mapdef.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/crawl-ref/source/mapdef.h b/crawl-ref/source/mapdef.h
index 822b811b5c..c6fcd7cef3 100644
--- a/crawl-ref/source/mapdef.h
+++ b/crawl-ref/source/mapdef.h
@@ -397,20 +397,22 @@ class mons_spec
{
public:
int mid;
- int monnum; // The zombified monster for zombies, or head
- // count for hydras, or colour for draconians.
+ monster_type monbase; // Base monster for zombies and dracs.
+ int number; // Head count for hydras
int genweight, mlevel;
bool fix_mons;
bool generate_awake;
- int colour;
+ int colour;
item_list items;
- mons_spec(int id = RANDOM_MONSTER, int num = MONS_PROGRAM_BUG,
+ mons_spec(int id = RANDOM_MONSTER,
+ monster_type base = MONS_PROGRAM_BUG,
+ int num = 0,
int gw = 10, int ml = 0,
bool _fixmons = false, bool awaken = false)
- : mid(id), monnum(num), genweight(gw), mlevel(ml), fix_mons(_fixmons),
- generate_awake(awaken), colour(BLACK), items()
+ : mid(id), monbase(base), number(num), genweight(gw), mlevel(ml),
+ fix_mons(_fixmons), generate_awake(awaken), colour(BLACK), items()
{
}
};